@@ -7,7 +7,9 @@ setMethod("sdDiff", signature(x="numeric"), function(x, na.rm=FALSE, diff=1L, ..
     x <- x[!is.na(x)];
   if (diff > 0L)
     x <- diff(x, differences=diff);
-  sd(x, na.rm=FALSE)/(sqrt(2)^diff);
+  sd <- sd(x, na.rm=FALSE)
+  x <- NULL; # Not needed anymore
+  sd/(sqrt(2)^diff);
 })
 
 
@@ -15,6 +17,8 @@ setMethod("sdDiff", signature(x="numeric"), function(x, na.rm=FALSE, diff=1L, ..
 
 ############################################################################
 # HISTORY:
+# 2013-11-23
+# o MEMORY: Now sdDiff() cleans out allocated objects sooner.
 # 2008-04-13
 # o Added varDiff().
 # 2008-04-10 [on UA930 SFO-LHR]
