@@ -20,7 +20,7 @@ for (addNA in c(FALSE, TRUE)) {
     stopifnot(identical(r1, r2))
     stopifnot(identical(r1, r3))
   }
-  
+
   # Row/column extremes
   for (na.rm in c(FALSE, TRUE)) {
     cat("na.rm=", na.rm, "\n", sep="")
@@ -30,7 +30,7 @@ for (addNA in c(FALSE, TRUE)) {
     m3 <- apply(x, MARGIN=1, FUN=min, na.rm=na.rm)
     stopifnot(identical(m1, m2))
     stopifnot(identical(m1, m3))
-  
+
     # Max
     m1 <- rowMaxs(x, na.rm=na.rm)
     m2 <- colMaxs(t(x), na.rm=na.rm)
@@ -40,7 +40,7 @@ for (addNA in c(FALSE, TRUE)) {
   }
 } # for (addNA ...)
 
-  
+
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # All NAs
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -55,3 +55,29 @@ for (na.rm in c(FALSE, TRUE)) {
   stopifnot(identical(r1, r2))
   stopifnot(identical(r1, r3))
 }
+
+
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+# Special cases
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+# Nx0 matrix
+x <- matrix(double(0L), nrow=5L, ncol=0L)
+r1 <- rowRanges(x)
+rT <- matrix(c(Inf,-Inf), nrow=nrow(x), ncol=2L, byrow=TRUE)
+stopifnot(identical(r1,rT))
+
+# 0xN matrix
+x <- t(x)
+r1 <- colRanges(x)
+stopifnot(identical(r1,rT))
+
+# Nx1 matrix
+x <- matrix(1:5, nrow=5L, ncol=1L)
+r1 <- rowRanges(x)
+rT <- matrix(1:5, nrow=nrow(x), ncol=2L, byrow=FALSE)
+stopifnot(identical(r1,rT))
+
+# 1xN matrix
+x <- t(x)
+r1 <- colRanges(x)
+stopifnot(identical(r1,rT))
